@@ -11,7 +11,7 @@ try:
         showwarning,
     )
     from tkinter.simpledialog import askstring
-except ImportError as error:
+except (ImportError, ModuleNotFoundError) as error:
     print(
         f"{error}. Please visit https://tkdocs.com/tutorial/install.html",
         "for help installing it.",
@@ -26,10 +26,9 @@ background_image = pkgutil.get_data(__name__, "images/background.png")
 icon = pkgutil.get_data(__name__, "images/icon.png")
 
 description = (
-    "A simple application to help speed up exploratory data analysis and "
-    "reporting. Select a file to analyse, and it will be automatically "
-    "summarised. The result is a report in Word format, complete with summary"
-    " statistics and graphs."
+    "Speed up exploratory data analysis & reporting.\n\n"
+    "Automatically analyze files, and get a Word report complete with "
+    "summary statistics and graphs."
 )
 
 
@@ -38,7 +37,7 @@ class EDAGUI(Frame):  # pragma: no cover
     interface* to the application.
 
     The "Select a file" button launches a *file-dialog* to navigate to and
-    select a file to analyse.
+    select a file to analyze.
 
     .. figure:: _static/screencast.*
        :alt: an image of the graphical user interface
@@ -59,18 +58,18 @@ class EDAGUI(Frame):  # pragma: no cover
     def __init__(self, master=None, **kwargs) -> None:
         super().__init__(master)
         self.master.title("eda-report")
-        self.master.geometry("600x360")
+        self.master.geometry("560x320")
         self.master.resizable(False, False)  # Fix window size
-        self.master.wm_iconphoto(True, PhotoImage(data=icon))  # Add icon
+        self.master.wm_iconphoto(True, PhotoImage(data=icon))
         self._create_widgets()
         self.pack()
 
     def _create_widgets(self) -> None:
         """Creates the widgets for the graphical user interface: A Tk *Frame*
         with the *canvas(background image)*, *introductory text*, and a
-        *button* to select files to analyse.
+        *button* to select files to analyze.
         """
-        self.canvas = Canvas(self, width=600, height=360)
+        self.canvas = Canvas(self, width=560, height=320)
 
         # Set background image
         self.bg_image = PhotoImage(data=background_image)
@@ -78,24 +77,24 @@ class EDAGUI(Frame):  # pragma: no cover
 
         # Add title
         self.canvas.create_text(
-            (90, 45),
+            (70, 30),
             anchor="nw",
             fill="black",
-            font=("Courier", 35, "bold"),
+            font=("Courier", 28, "bold"),
             text="eda-report",
         )
 
         # Add introductory text
         self.canvas.create_text(
-            (40, 105),
+            (40, 90),
             anchor="nw",
             fill="black",
             font=("Courier", 12),
             text=description,
-            width=500,
+            width=480,
         )
 
-        # Add a button to select input files
+        # Add a button to select input file
         self.button = Button(
             self,
             bg="#204060",
@@ -107,19 +106,19 @@ class EDAGUI(Frame):  # pragma: no cover
             text="Select a file",
         )
         self.canvas.create_window(
-            (175, 250), anchor="nw", height=40, width=250, window=self.button
+            (180, 220), anchor="nw", height=40, width=200, window=self.button
         )
 
         # Show current action
         self.current_action = StringVar()
         self.display_current_action = Label(
             self,
-            bg="#dfddde",
+            bg="#c0d6e3",
             font=("Courier", 10, "italic"),
             textvariable=self.current_action,
         )
         self.canvas.create_window(
-            (140, 315),
+            (140, 280),
             anchor="nw",
             window=self.display_current_action,
         )
@@ -147,7 +146,7 @@ class EDAGUI(Frame):  # pragma: no cover
             self.current_action.set("Analysing data & compiling the report...")
             self._get_save_as_name()
 
-            # Generate the report using the collected arguments
+            # Generate and save the report using the collected arguments
             ReportDocument(
                 self.data,
                 title=self.report_title,
@@ -161,12 +160,15 @@ class EDAGUI(Frame):  # pragma: no cover
             # Clear stale data to free up memory
             del self.data
 
-    def _get_data_from_file(self, retries=1) -> None:
+    def _get_data_from_file(self, retries: int = 1) -> None:
         """Creates a file dialog to help navigate to and select a file to
-        analyse.
+        analyze.
+
+        Args:
+            retries (int): Number of additional prompts, if input is invalid.
         """
         file_name = askopenfilename(
-            title="Select a file to analyse",
+            title="Select a file to analyze",
             filetypes=(
                 ("All supported formats", ("*.csv", "*.xlsx")),
                 ("csv", "*.csv"),
@@ -222,17 +224,17 @@ class EDAGUI(Frame):  # pragma: no cover
         """Creates a graphical color picking tool to help set the desired
         color for the generated graphs.
         """
-        # Returns a tuple e.g ((255.99609375, 69.26953125, 0.0), '#ff4500').
         color = askcolor(
             color="cyan", title="Please select a color for the graphs"
-        )[-1]
-        self.graph_color = color or "cyan"
+        )
+        # Pick the hexadecimal color format. `askcolor` returns a tuple e.g
+        # ((255.99609375, 69.26953125, 0.0), '#ff4500').
+        self.graph_color = color[-1] or "cyan"
 
     def _get_save_as_name(self) -> None:
         """Create a file dialog to help select a destination folder and file
         name for the generated report.
         """
-        # Propmt user for desired output file-name
         save_name = asksaveasfilename(
             initialdir=".",
             initialfile="eda-report.docx",
